#
# spec file for package hyprutils
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Florian "sp1rit" <sp1rit@disroot.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           hyprutils
Version:        0.2.6
Release:        1.1
Summary:        Utilities used across the Hypr* ecosystem
License:        BSD-3-Clause
URL:            https://github.com/hyprwm/hyprutils
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++ >= 9
BuildRequires:  pkgconfig(pixman-1)

%package -n lib%{name}%{sover}
Summary:        Library for the hyprland cursor format
Group:          System/Libraries

%package devel
Summary:        Development files for hyprcursor
Group:          Development/Libraries/Other
Requires:       lib%{name}%{sover} = %{version}

%define _description %{expand:
Hyprutils is a small C++ library for utilities used across the Hypr*
ecosystem.}

%description %{_description}

%description -n lib%{name}%{sover} %{_description}

%description devel %{_description}

This subpackage contains development files for hyprcursor.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post   -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%license LICENSE
%{_libdir}/lib%{name}.so.%{sover}
%{_libdir}/lib%{name}.so.%{version}

%files devel
%license LICENSE
%doc README.md
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Dec 17 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to version 0.2.6:
  + A small update with small stuff.
  + Additions:
  - os: added addEnv to Process
  + Other:
  - os: fixed some zombie processes being left with Process
- Changes from version 0.2.5:
  + Minor fixes to process and bsd
  + Fixes:
  - os: Fixed deadlock when pipes overflow the 64k buffer size.
- Changes from version 0.2.4:
  + A small update to add hyprutils/OS
  + Additions:
  - os: Add process
* Thu Sep 26 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 0.2.3:
  * Math: add Mat3x3
- Changes from 0.2.2:
  * string: fixup isNumber not accepting -1.0
* Thu Aug  8 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to version 0.2.1:
  + A small, ABI-compatible update to add Edges.
  + Other:
  - Add Edges type and Box::extent() for its bottom right corner
- Changes from version 0.2.0:
  + A major release which also breaks ABI compat, as such bumping the
    sover.
  + Fixes:
  - math: avoid assert fail in std::clamp in closestPoint
  - math/region: add expand
  - memory: do not release pointers after emitting a signal
  - adjust right and bottom box edges when getting closest point
  + Other:
  - avoid undefined behaviour from downcasting ptr implentation
  - string: respect removeEmpty when VarList input is empty
  - path: add findConfig and dir utils
* Wed Jun 26 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to version 0.1.5:
  + A small update with a few patches.
  + Fixes:
  - Math: fixed macro collisions with hyprland
  + Other:
  - Added some constants to handle floating point presicion
    comparisons
  - Minor Box improvements
- Changes from version 0.1.4:
  + This is an update that adds a few new stuff under Math
  + Additions:
  - Math: added Vector2D, Region and Box
- Changes from version 0.1.3:
  + A small update to fix String::isNumber sometimes being wrong.
  + Fixes:
  - String: fix isNumber accepting - as a number
* Thu Jun 13 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Initial packaging of hyprutils 0.1.2
